
///////////////////////////////////////////////////////////////////////////////
//
//   ROCKWELL SEMICONDUCTOR SYSTEMS - COMMERCIAL GPS BUSINESS
//
///////////////////////////////////////////////////////////////////////////////
//
//
//   MSG1211.C - Message 1211 Processing
// 
//
//   DESCRIPTION
//
//   Functions to decode, build, and display Zodiac 1211 messages.
//
//
//   REVISION HISTORY
//
//   $Log:   V:\Projects\Labmon\Source\Archives\MSG1211.C_V  $
//   
//      Rev 1.15   09 Nov 1998 10:47:58   phungh
//   labmon51: Fix file logging and missing
//   logged data bugs.  Changes made to the 
//   "Pause" variable ( 1 -> 0 ) to allow main
//   loop continue.  Move the "write to file"
//   code portion out of the interrupt handler
//   so that data is not missed because of time
//   spent too long in the interrupt handler
//   
//      Rev 1.3   Jul 09 1997 10:46:12   COLEJ
//    
//   
//      Rev 1.2   Feb 12 1997 16:05:32   COLEJ
//    
//   
//      Rev 1.1   Aug 13 1996 13:47:58   COLEJ
//    
//   
//      Rev 1.0   13 May 1996 14:53:04   GPSADMIN
//   Initial release to version control.
//
//
////////////////////////////////////////////////////////////////////////////////

#include <string.h>

#include "gentypes.h"
#include "ztypes.h"
#include "zcons.h"
#include "util.h"   

////////////////////////////////////////////////////////////////////////////////
//   
//   Decode a Zodiac 1211 message from the ZMsgBuf.
//
void Dec1211(tMSGBUF *ZMsgBuf, tMSG1211 *Msg)
{   
   GetShort  (&Msg->SequenceNumber         , ZMsgBuf, 6);    // ND   
   GetUShort (&Msg->DatumID                , ZMsgBuf, 7);    // ND 
}

////////////////////////////////////////////////////////////////////////////////
//   
//   Build a Zodiac 1211 message in the ZMsgBuf. 
//
void Bld1211(tMSGBUF *ZMsgBuf, tMSG1211 *Msg)
{
   // copy message into buffer
   memcpy(((tSHORT *) ZMsgBuf)+5, Msg, sizeof(*Msg));          

   // build the header in the buffer
   PutShort  (0x81FF                      , ZMsgBuf, 1);    // message preamble
   PutShort  (1211                        , ZMsgBuf, 2);    // message number
   PutShort  (2                           , ZMsgBuf, 3);    // message length 
   PutShort  (ANREQ                       , ZMsgBuf, 4);    // message ack/nack request
    
   PutShort  (Msg->SequenceNumber         , ZMsgBuf, 6);    // ND   
   PutUShort (Msg->DatumID                , ZMsgBuf, 7);    // ND 
}
